@@ -15,9 +15,11 @@ import pandas as pd
 from PyFin.Enums import Factors
 from PyFin.Analysis.SeriesValues import SeriesValues
 from PyFin.Analysis.SecurityValueHolders import FilteredSecurityValueHolder
+from PyFin.Analysis.SecurityValueHolders import SecurityCurrentValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityLatestValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityIIFValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityShiftedValueHolder
+from PyFin.Analysis.SecurityValueHolders import SecurityDeltaValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityConstArrayValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAverage
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMax
@@ -787,8 +789,8 @@ class TestSecurityValueHolders(unittest.TestCase):
 
         shifted1.push(data2)
         expected = SeriesValues({'aapl': 1.0,
-                                   'ibm': 2.0,
-                                   'goog': 3.0})
+                                 'ibm': 2.0,
+                                 'goog': 3.0})
         calculated = shifted1.value
         for name in expected.index():
             self.assertAlmostEqual(expected[name], calculated[name])
@@ -799,12 +801,55 @@ class TestSecurityValueHolders(unittest.TestCase):
 
         shifted1.push(data3)
         expected = SeriesValues({'aapl': 1.5,
-                                   'ibm': 2.5,
-                                   'goog': 3.5})
+                                 'ibm': 2.5,
+                                 'goog': 3.5})
         calculated = shifted1.value
         for name in expected.index():
             self.assertAlmostEqual(expected[name], calculated[name])
 
+    def testDeltaSecurityValueHolder(self):
+        mm = SecurityMovingAverage(2, 'close')
+        delta1 = SecurityDeltaValueHolder(mm, 2)
+
+        data1 = {'aapl': {'close': 1.0},
+                 'ibm': {'close': 2.0},
+                 'goog': {'close': 3.0}}
+        delta1.push(data1)
+        calculated = delta1.value
+        for name in calculated.index():
+            self.assertTrue(np.isnan(calculated[name]))
+
+        data2 = {'aapl': {'close': 2.0},
+                 'ibm': {'close': 3.0},
+                 'goog': {'close': 4.0}}
+
+        delta1.push(data2)
+
+        data3 = {'aapl': {'close': 3.0},
+                 'ibm': {'close': 4.0},
+                 'goog': {'close': 5.0}}
+
+        delta1.push(data3)
+
+        expected = SeriesValues({'aapl': 1.5,
+                                 'ibm': 1.5,
+                                 'goog': 1.5})
+        calculated = delta1.value
+        for name in expected.index():
+            self.assertAlmostEqual(expected[name], calculated[name])
+
+        data4 = ({'aapl': {'close': 4.0},
+                  'ibm': {'close': 5.0},
+                  'goog': {'close': 6.0}})
+
+        delta1.push(data4)
+        expected = SeriesValues({'aapl': 2.0,
+                                 'ibm': 2.0,
+                                 'goog': 2.0})
+        calculated = delta1.value
+        for name in expected.index():
+            self.assertAlmostEqual(expected[name], calculated[name])
+
     def testShiftedSecurityValueHolderWithLengthZero(self):
         mm = SecurityMovingAverage(2, 'close')
         with self.assertRaises(ValueError):
@@ -1023,6 +1068,50 @@ class TestSecurityValueHolders(unittest.TestCase):
         np.testing.assert_array_almost_equal(calculated['new_factor'].values[1:],
                                              expected['close'].values[1:])
 
+    def testSecurityCurrentValueHolder(self):
+        current = SecurityCurrentValueHolder('x')
+
+        data1 = dict(aapl=dict(x=1),
+                     ibm=dict(x=2))
+
+        current.push(data1)
+        calculated = current.value
+        for name in data1.keys():
+            self.assertAlmostEqual(data1[name]['x'], calculated[name])
+
+        data2 = dict(aapl=dict(x=3),
+                     ibm=dict(x=np.nan))
+        current.push(data2)
+        calculated = current.value
+        for name in data1.keys():
+            expected = data2[name]['x']
+            if not np.isnan(expected):
+                self.assertAlmostEqual(expected, calculated[name])
+            else:
+                self.assertTrue(np.isnan(calculated[name]))
+
+    def testSecurityLatestValueHolder(self):
+        latest = SecurityLatestValueHolder('x')
+
+        data1 = dict(aapl=dict(x=1),
+                     ibm=dict(x=2))
+
+        latest.push(data1)
+        calculated = latest.value
+        for name in data1.keys():
+            self.assertAlmostEqual(data1[name]['x'], calculated[name])
+
+        data2 = dict(aapl=dict(x=3),
+                     ibm=dict(x=np.nan))
+        latest.push(data2)
+        calculated = latest.value
+        for name in data1.keys():
+            expected = data2[name]['x']
+            if not np.isnan(expected):
+                self.assertAlmostEqual(expected, calculated[name])
+            else:
+                self.assertAlmostEqual(data1[name]['x'], calculated[name])
+
     def testSecurityLatestValueHolderDeepcopy(self):
         latest = SecurityLatestValueHolder('x')
 
